==> haskell-profunctors-5.2-25-i686.pkg.tar.xz: usr/share/haskell/register/haskell-profunctors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: profunctors
version: 5.2
id: profunctors-5.2-4zjFZFPovmkGmxhqVQbvW7
key: profunctors-5.2-4zjFZFPovmkGmxhqVQbvW7
license: BSD3
copyright: Copyright (C) 2011-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/profunctors/
synopsis: Profunctors
description:
    Profunctors
category: Control, Categories
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Profunctor Data.Profunctor.Adjunction Data.Profunctor.Cayley
    Data.Profunctor.Choice Data.Profunctor.Closed
    Data.Profunctor.Composition Data.Profunctor.Mapping
    Data.Profunctor.Monad Data.Profunctor.Ran Data.Profunctor.Rep
    Data.Profunctor.Sieve Data.Profunctor.Strong
    Data.Profunctor.Traversing Data.Profunctor.Types
    Data.Profunctor.Unsafe
abi: 61eb59f4812b4d3480ef2f7e9e64e1c9
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/profunctors-5.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/profunctors-5.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/profunctors-5.2
hs-libraries: HSprofunctors-5.2-4zjFZFPovmkGmxhqVQbvW7
depends:
    base-4.9.0.0 base-orphans-0.6-5PayU02PR2MEqN5xZtCkua
    bifunctors-5.4.1-3Bt0uHr1oX028awtoQqPKR
    comonad-5-BXS82knsrtd4kXV7rg0uf7
    contravariant-1.4-KgMYVwXYQBGKuyyJtYdP11
    distributive-0.5.2-4LsZjgK7w7a5vNYTgeYpWm
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-profunctors/html/profunctors.haddock
haddock-html: /usr/share/doc/haskell-profunctors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-profunctors-5.2-28-i686.pkg.tar.xz: usr/share/haskell/register/haskell-profunctors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: profunctors
version: 5.2
id: profunctors-5.2-BK9PDuHw2BPIuZitSy103t
key: profunctors-5.2-BK9PDuHw2BPIuZitSy103t
license: BSD3
copyright: Copyright (C) 2011-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/profunctors/
synopsis: Profunctors
description:
    Profunctors
category: Control, Categories
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Profunctor Data.Profunctor.Adjunction Data.Profunctor.Cayley
    Data.Profunctor.Choice Data.Profunctor.Closed
    Data.Profunctor.Composition Data.Profunctor.Mapping
    Data.Profunctor.Monad Data.Profunctor.Ran Data.Profunctor.Rep
    Data.Profunctor.Sieve Data.Profunctor.Strong
    Data.Profunctor.Traversing Data.Profunctor.Types
    Data.Profunctor.Unsafe
abi: 243e7b46c269d4eacdeba7c104723009
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/profunctors-5.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/profunctors-5.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/profunctors-5.2
hs-libraries: HSprofunctors-5.2-BK9PDuHw2BPIuZitSy103t
depends:
    base-4.9.0.0 base-orphans-0.6-5PayU02PR2MEqN5xZtCkua
    bifunctors-5.4.2-89Yr6mDv1GYKyj9AXEUlAj
    comonad-5.0.1-EAitB0Um1u97dvApDogomX
    contravariant-1.4-BhMeiKXigEF6jqFehOEdeG
    distributive-0.5.2-4LsZjgK7w7a5vNYTgeYpWm
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-profunctors/html/profunctors.haddock
haddock-html: /usr/share/doc/haskell-profunctors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
